@@ -35,9 +35,7 @@
 
 #include "../postgis_config.h"
 
-#if POSTGIS_PGSQL_VERSION >= 100
 #include <utils/regproc.h>
-#endif
 
 #include "liblwgeom.h"
 #include "lwgeom_pg.h"
@@ -117,8 +115,17 @@ static Oid
 postgis_get_full_version_schema()
 {
 	const char* proname = "postgis_full_version";
+	#if POSTGIS_PGSQL_VERSION < 160
 	List* names = stringToQualifiedNameList(proname);
+	#else
+	List* names = stringToQualifiedNameList(proname, NULL);
+	#endif
+
+	#if POSTGIS_PGSQL_VERSION < 140
 	FuncCandidateList clist = FuncnameGetCandidates(names, -1, NIL, false, false, false);
+	#else
+	FuncCandidateList clist = FuncnameGetCandidates(names, -1, NIL, false, false, false, false);
+	#endif
 	if (!clist)
 		return InvalidOid;
 
@@ -513,11 +520,15 @@ postgis_guc_find_option(const char *name)
 	 * By equating const char ** with struct config_generic *, we are assuming
 	 * the name field is first in config_generic.
 	 */
+#if POSTGIS_PGSQL_VERSION >= 160
+	res = (struct config_generic **) find_option((void *) &key, false, true, ERROR);
+#else
 	res = (struct config_generic **) bsearch((void *) &key,
 		 (void *) get_guc_variables(),
 		 GetNumConfigOptions(),
 		 sizeof(struct config_generic *),
 		 postgis_guc_var_compare);
+#endif
 
 	/* Found nothing? Good */
 	if ( ! res ) return 0;
@@ -531,51 +542,6 @@ postgis_guc_find_option(const char *name)
 }
 
 
-#if POSTGIS_PGSQL_VERSION < 100
-Datum
-CallerFInfoFunctionCall1(PGFunction func, FmgrInfo *flinfo, Oid collation, Datum arg1)
-{
-	FunctionCallInfoData fcinfo;
-	Datum		result;
-
-	InitFunctionCallInfoData(fcinfo, flinfo, 1, collation, NULL, NULL);
-
-	fcinfo.arg[0] = arg1;
-	fcinfo.argnull[0] = false;
-
-	result = (*func) (&fcinfo);
-
-	/* Check for null result, since caller is clearly not expecting one */
-	if (fcinfo.isnull)
-		elog(ERROR, "function %p returned NULL", (void *) func);
-
-	return result;
-}
-
-Datum
-CallerFInfoFunctionCall2(PGFunction func, FmgrInfo *flinfo, Oid collation, Datum arg1, Datum arg2)
-{
-	FunctionCallInfoData fcinfo;
-	Datum		result;
-
-	InitFunctionCallInfoData(fcinfo, flinfo, 2, collation, NULL, NULL);
-
-	fcinfo.arg[0] = arg1;
-	fcinfo.arg[1] = arg2;
-	fcinfo.argnull[0] = false;
-	fcinfo.argnull[1] = false;
-
-	result = (*func) (&fcinfo);
-
-	/* Check for null result, since caller is clearly not expecting one */
-	if (fcinfo.isnull)
-		elog(ERROR, "function %p returned NULL", (void *) func);
-
-	return result;
-}
-
-#else
-
 #if POSTGIS_PGSQL_VERSION < 120
 Datum
 CallerFInfoFunctionCall3(PGFunction func, FmgrInfo *flinfo, Oid collation, Datum arg1, Datum arg2, Datum arg3)
@@ -626,5 +592,3 @@ CallerFInfoFunctionCall3(PGFunction func, FmgrInfo *flinfo, Oid collation, Datum
     return result;
 }
 #endif
-
-#endif
